@@ -24,7 +24,7 @@
   @author Copyright (C) 2004 Philippe April <papril777@yahoo.com>
   @author Copyright (C) 2004 Alexandre Carmel-Veilleux <acv@miniguru.ca>
   @author Copyright (C) 2008 Paul Kube <nodogsplash@kokoro.ucsd.edu>
-  @author Copyright (C) 2015-2022 Modifications and additions by BlueWave Projects and Services <opennds@blue-wave.net>
+  @author Copyright (C) 2015-2023 Modifications and additions by BlueWave Projects and Services <opennds@blue-wave.net>
  */
 
 
@@ -295,6 +295,7 @@ setup_from_config(void)
 	t_WGFQDN *allowed_wgfqdn;
 	char wgfqdns[1024] = {0};
 	char *dnscmd;
+	char *setupcmd;
 
 	s_config *config;
 
@@ -320,6 +321,16 @@ setup_from_config(void)
 	// Before we do anything else, reset the firewall (cleans it, in case we are restarting after opennds crash)
 	iptables_fw_destroy();
 
+	// Call pre setup library function
+	safe_asprintf(&setupcmd, "/usr/lib/opennds/libopennds.sh \"pre_setup\"");
+	msg = safe_calloc(STATUS_BUF);
+
+	if (execute_ret_url_encoded(msg, STATUS_BUF - 1, setupcmd) == 0) {
+		debug(LOG_INFO, "Pre-Setup request sent");
+	}
+	free(setupcmd);
+	free(msg);
+
 	// Check for libmicrohttp version at runtime, ie actual installed version
 	int major = 0;
 	int minor = 0;
